@@ -17,6 +17,6 @@ def test_example1(lockable_resource):
 def test_example2(lockable_resource, lockable):
     """ Simple test """
     print(f'Testing with resource: {lockable_resource}')
-    with lockable({}) as resource:
-        print(f'Testing with resource#2: {resource}')
+    with lockable.auto_lock({}) as allocation:
+        print(f'Testing with resource#2: {allocation}')
         sleep(1)
